A dataframe with
- all variables in the linear model,
- absolute extremeness (absolute value of difference between variable
score and mean value of variable),
- extremeness (difference between variable score and mean value of
variable), which can be useful when the direction of extremeness is relevant.
The rows are ordered in decreasing order of the absolute extreme values.